@@ -73,7 +73,7 @@ new CloudFrontToMediaStore(this, "test-cloudfront-mediastore-default", new Cloud
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|cloudFrontWebDistribution|[`cloudfront.CloudFrontWebDistribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.CloudFrontWebDistribution.html)|Returns an instance of cloudfront.CloudFrontWebDistribution created by the construct.|
+|cloudFrontWebDistribution|[`cloudfront.Distribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.Distribution.html)|Returns an instance of cloudfront.Distribution created by the construct.|
 |mediaStoreContainer|[`mediastore.CfnContainer`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-mediastore.CfnContainer.html)|Returns an instance of mediastore.CfnContainer.|
 |cloudFrontLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket as the logging bucket for the CloudFront Web Distribution.|
 |cloudFrontOriginRequestPolicy|[`cloudfront.OriginRequestPolicy`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.OriginRequestPolicy.html)|Returns an instance of cloudfront.OriginRequestPolicy created by the construct for the CloudFront Web Distribution.|
@@ -89,7 +89,7 @@ Out of the box implementation of the Construct without any override will set the
 * Configure access logging for CloudFront Web Distribution
 * Enable CloudFront Origin Request Policy for AWS Elemental MediaStore Container
 * Set `User-Agent` custom header with CloudFront Origin Access Identity
-* Enable automatic injection of best practice HTTP security headers in all responses from CloudFront WebDistribution
+* Enable automatic injection of best practice HTTP security headers in all responses from CloudFront Distribution
 
 ### AWS Elemental MediaStore
 
@@ -120,6 +120,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudfront
@@ -139,10 +141,10 @@ class CloudFrontToMediaStore(
         id: builtins.str,
         *,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        media_store_container_props: typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps] = None,
+        media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -157,6 +159,10 @@ class CloudFrontToMediaStore(
         :since: 1.76.0
         :summary: Constructs a new instance of CloudFrontToMediaStore class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudFrontToMediaStore.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToMediaStoreProps(
             cloud_front_distribution_props=cloud_front_distribution_props,
             cloud_front_logging_bucket_props=cloud_front_logging_bucket_props,
@@ -218,10 +224,10 @@ class CloudFrontToMediaStoreProps:
         self,
         *,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        media_store_container_props: typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps] = None,
+        media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
@@ -236,6 +242,13 @@ class CloudFrontToMediaStoreProps:
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(media_store_container_props, dict):
             media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudFrontToMediaStoreProps.__init__)
+            check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
+            check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
+            check_type(argname="argument existing_media_store_container_obj", value=existing_media_store_container_obj, expected_type=type_hints["existing_media_store_container_obj"])
+            check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
+            check_type(argname="argument media_store_container_props", value=media_store_container_props, expected_type=type_hints["media_store_container_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if cloud_front_distribution_props is not None:
             self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
